<?xml version="1.0" encoding="Shift_JIS"?>
<xsl:stylesheet version="1.0"
     xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:include href="css_document.xsl"/>
	<xsl:template match="/">
	  <xsl:apply-templates />
	</xsl:template>

	<xsl:template match="docs">
		<html>
			<head>
				<title><xsl:value-of select="@title" /></title>
				<meta http-equiv="Content-Type" content="text/html; charset=shift-jis"/>
				<xsl:call-template name="css"/>
			</head>
			<body>
				<table class="docs">
					<tr><td class="docs"><xsl:value-of select="@title" /><hr class="docs"/></td></tr>
					<tr><td><xsl:apply-templates /></td></tr>
					<tr><td>
						<hr class="docs"/>
						<xsl:call-template name="footnotes"/>
					</td></tr>
				</table>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="capter">
		<table class="capter">
			<tr><td class="capter"><xsl:call-template name ="numbering"/> <xsl:value-of select="@title" /></td></tr>
			<tr><td class="indent"><xsl:apply-templates /></td></tr>
		</table>
	</xsl:template>

	<xsl:template match="section">
		<table class="section">
			<tr><td class="section"><xsl:call-template name ="numbering"/> <xsl:value-of select="@title" /></td></tr>
			<tr><td class="indent"><xsl:apply-templates /></td></tr>
		</table>
	</xsl:template>

	<xsl:template match="subsection">
		<table class="subsection">
			<tr><td class="subsection"><xsl:call-template name ="numbering"/> <xsl:value-of select="@title" /></td></tr>
			<tr><td class="indent"><xsl:apply-templates /></td></tr>
		</table>
	</xsl:template>

	<xsl:template match="paragraph">
		<table class="paragraph">
			<tr><td class="paragraph"><xsl:call-template name ="numbering"/> <xsl:value-of select="@title" /></td></tr>
			<tr><td class="indent"><xsl:apply-templates /></td></tr>
		</table>
	</xsl:template>

	<xsl:template match="link">
		<xsl:choose>
			<xsl:when test='not(text()) and contains(@href,".xml")'>
				<a>
					<xsl:attribute name="href"><xsl:value-of select="@href" /></xsl:attribute>
					<xsl:attribute name="target">IM_MAIN</xsl:attribute>
					<xsl:for-each select="document(@href)/docs">
						<xsl:value-of select="@title"/>
					</xsl:for-each>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<a>
					<xsl:attribute name="href"><xsl:value-of select="@href" /></xsl:attribute>
					<xsl:attribute name="target">IM_MAIN</xsl:attribute>
					<xsl:apply-templates/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="footnote">
		<a>
			<xsl:attribute name="href">#note<xsl:number level="single" format="1"/></xsl:attribute>
			<xsl:attribute name="title"><xsl:value-of select="@note" /></xsl:attribute>
			<span class="ref-footnote">*<xsl:number level="single" format="1"/></span>
		</a>
	</xsl:template>

	<xsl:template match="red">
		<span class="text-red"><xsl:apply-templates /></span>
	</xsl:template>

	<xsl:template match="blue">
		<span class="text-blue"><xsl:apply-templates /></span>
	</xsl:template>

	<xsl:template match="program">
		<table class="program">
			<tr><td class="program"><pre><xsl:value-of select='substring(translate(text(),"&#x9;",""),2)' /></pre></td></tr>
		</table>
	</xsl:template>

	<xsl:template match="std-table">
		<table class="std">
			<xsl:for-each select='tr'>
				<xsl:copy>
					<xsl:for-each select="@*">
						<xsl:copy />
					</xsl:for-each>
					<xsl:attribute name="class">std</xsl:attribute>
					<xsl:for-each select='th|td'>
						<xsl:copy>
							<xsl:for-each select="@*">
								<xsl:copy />
							</xsl:for-each>
							<xsl:attribute name="class">std</xsl:attribute>
							<xsl:apply-templates />
						</xsl:copy>
					</xsl:for-each>
				</xsl:copy>
			</xsl:for-each>
		</table>
	</xsl:template>

	<xsl:template match="br">
		<br/>
	</xsl:template>

	<xsl:template match="node()">
		<xsl:copy>
			<xsl:for-each select="@*">
				<xsl:copy />
			</xsl:for-each>
			<xsl:apply-templates />
		</xsl:copy>
	</xsl:template>

	<xsl:template name="numbering"> 
		<xsl:number level="multiple" format="1." count="capter|section|subsection|paragraph"/>
	</xsl:template>

	<xsl:template name="footnotes"> 
		<xsl:for-each select="//footnote" >
			<a>
				<xsl:attribute name="name">note<xsl:number level="single" format="1"/></xsl:attribute>
			</a>
			<span class="footnote">*<xsl:number level="single" format="1"/> : <xsl:value-of select="@note" /></span><br/>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
